@@ -22,8 +22,8 @@ import siputils
 
 
 # Initialise the globals.
-sip_version = 0x040405
-sip_version_str = "4.4.5"
+sip_version = 0x040500
+sip_version_str = "4.5"
 py_version = sys.hexversion >> 8
 plat_py_site_dir = None
 plat_py_inc_dir = None
@@ -47,7 +47,7 @@ opt_export_all = 0
 # The names of build macros extracted from the platform specific configuration
 # files.
 build_macro_names = [
-    "DEFINES",
+    "DEFINES", "CONFIG",
     "CC",
     "CFLAGS",
     "CFLAGS_RELEASE", "CFLAGS_DEBUG",
@@ -218,13 +218,23 @@ def set_platform_directories():
     else:
         vers = "%d.%d" % ((py_version >> 16) & 0xff, (py_version >> 8) & 0xff)
 
-        plat_py_site_dir = sys.prefix + "/lib/python" + vers
+        # Some 64 bit Linux distros (Mandriva, SuSE) seem to add sys.lib as a
+        # non-standard extension presumably to allow 32 and 64 bit versions to
+        # be installed side by side.  Use it if it seems to be available.
+        try:
+            lib_dir = sys.lib
+        except AttributeError:
+            lib_dir = "lib"
+
+        lib_dir = sys.prefix + "/" + lib_dir + "/python" + vers
+
+        plat_py_site_dir = lib_dir
         if py_version >= 0x020000:
             plat_py_site_dir = plat_py_site_dir + "/site-packages"
 
         plat_py_inc_dir = sys.prefix + "/include/python" + vers
         plat_py_conf_inc_dir = sys.exec_prefix + "/include/python" + vers
-        plat_py_lib_dir = sys.prefix + "/lib/python" + vers + "/config"
+        plat_py_lib_dir = lib_dir + "/config"
         plat_bin_dir = sys.exec_prefix + "/bin"
         plat_sip_dir = sys.prefix + "/share/sip"
 
@@ -240,6 +250,7 @@ def create_config(module, template, macros):
     siputils.inform("Creating %s..." % module)
 
     content = {
+        "sip_config_args":  sys.argv[1:],
         "sip_version":      sip_version,
         "sip_version_str":  sip_version_str,
         "platform":         opt_platform,
